/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.nlpcraft.client.models;

import org.apache.nlpcraft.model.NCElement;
import org.apache.nlpcraft.model.NCIntent;

import java.util.HashSet;
import java.util.Set;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * Test model.
 */
public class NCDialogSpecModel extends NCSpecModelAdapter {
    public static final String MDL_ID = NCDialogSpecModel.class.getSimpleName();

    @Override
    public String getId() {
        return MDL_ID;
    }

    @Override
    public Set<NCElement> getElements() {
        return Stream.of(mkElement("test1"), mkElement("test2")).collect(Collectors.toCollection(HashSet::new));
    }

    @NCIntent("intent=intentId1 term~{tok_id() == 'test1'}")
    public org.apache.nlpcraft.model.NCResult onTest1() {
        return org.apache.nlpcraft.model.NCResult.text("OK");
    }

    // Flow - `intentId1` must be one time.
    @NCIntent("intent=intentId2 flow='^(?:intentId1)(^:intentId1)*$' term~{tok_id() == 'test2'}")
    public org.apache.nlpcraft.model.NCResult onTest2() {
        return org.apache.nlpcraft.model.NCResult.text("OK");
    }
}
